<?php

class OAuth {
    public $network;
    private $client_id;
    private $client_key;
    private $access_uri;
    private $profile_uri;
    private $parameters;
    
    public function __construct($config = []) {
        $this->network = $config['network'];
        $this->client_id = $config['client_id'];
        $this->client_key = $config['client_key'];
        $this->access_uri = $config['access_uri'];
        $this->profile_uri = $config['profile_uri'];
        $this->parameters = $config['parameters'];
    }
    
    private function curl($url, $parameters = false) {
        $curl = curl_init($url);
        
        if($parameters) {
            curl_setopt($curl, CURLOPT_POSTFIELDS, urldecode(http_build_query($parameters)));
            curl_setopt($curl, CURLOPT_POST, true);
        }
        
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        
        $response = curl_exec($curl);
        
        curl_close($curl);
        return $response;
    }
    
    public function setToken($code) {
        $parameters = [
            'client_id' => $this->client_id,
            'client_secret' => $this->client_key,
            'redirect_uri' => REDIRECT,
            'grant_type' => 'authorization_code',
            'code' => $code,
        ];
        
        $response = $this->curl($this->access_uri, $parameters);
        $data = json_decode($response, true);
        
        if(isset($data['access_token'])) {
            return $this->getData($data['access_token']);
        }
        
        return false;
    }
    
    private function getData($token) {
        $parameters = $this->parameters;
        $parameters += ['access_token'  => $token];
        
        $response = $this->curl($this->profile_uri . '?' . urldecode(http_build_query($parameters)));
        $data = json_decode($response, true);
        
        switch($this->network) {
            case 'vk':
                if(isset($data['response'][0]['id'])) {
                    return $data['response'][0];
                }
                
                return false;
            break;
            case 'fb':
                if(isset($data['id'])) {
                    return $data;
                }
                
                return false;
            break;
            case 'gl':
                if(isset($data['id'])) {
                    return $data;
                }
                
                return false;
            break;
        }
    }
}
